==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionSeparatorInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionSeparatorInfoDescription } from "./ToolActionSeparatorInfoDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorInfoDescriptionMetadata.a == null) {
                ToolActionSeparatorInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorInfoDescriptionMetadata.c(ToolActionSeparatorInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionSeparatorInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionSeparatorInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("Size", "Number:double");
            a.item("IsGroupHeaderSeparator", "Boolean");
        }
        static d(a) {
            ToolActionSeparatorInfoDescriptionMetadata.b(a);
            a.ad("ToolActionSeparatorInfo", () => new ToolActionSeparatorInfoDescription());
            a.ac("ToolActionSeparatorInfo", ToolActionSeparatorInfoDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorInfoDescriptionMetadata.$t = markType(ToolActionSeparatorInfoDescriptionMetadata, 'ToolActionSeparatorInfoDescriptionMetadata');
    ToolActionSeparatorInfoDescriptionMetadata.a = null;
    return ToolActionSeparatorInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionSeparatorInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionSeparatorInfoDescription } from "./ToolActionSeparatorInfoDescription";
/**
 * @hidden
 */
export let ToolActionSeparatorInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionSeparatorInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionSeparatorInfoDescriptionMetadata.a == null) {
                ToolActionSeparatorInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionSeparatorInfoDescriptionMetadata.c(ToolActionSeparatorInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionSeparatorInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionSeparatorInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("Size", "Number:double");
            a.item("IsGroupHeaderSeparator", "Boolean");
        }
        static d(a) {
            ToolActionSeparatorInfoDescriptionMetadata.b(a);
            a.ae("ToolActionSeparatorInfo", () => new ToolActionSeparatorInfoDescription());
            a.ad("ToolActionSeparatorInfo", ToolActionSeparatorInfoDescriptionMetadata.a);
        }
    }
    ToolActionSeparatorInfoDescriptionMetadata.$t = markType(ToolActionSeparatorInfoDescriptionMetadata, 'ToolActionSeparatorInfoDescriptionMetadata');
    ToolActionSeparatorInfoDescriptionMetadata.a = null;
    return ToolActionSeparatorInfoDescriptionMetadata;
})();
